/**
 * The main entrypoint when using Tsx as the runtime
 */
import { IRuntime, RunTimeType } from '../common/runtime.ts';
import { process } from '../common/runtime/node.ts';
import TsxTerminalIO from '../common/runtime/terminal_io.ts';
import FileIO from '../common/runtime/file_io.ts';

/**
 * The Tsx Runtime implementation
 */
const TsxRuntime: IRuntime = {
	name: RunTimeType.Tsx,
	file: FileIO,
	term: TsxTerminalIO,
	onEvent: (eventName: string, handler) => process.on(eventName, handler),
	onExit: (cb: () => void): void => {
		process.on('beforeExit', cb);
		process.on('exit', cb);
		process.on('SIGINT', cb);
	},
	exit: (code?: number) => process.exit(code),
};

export default TsxRuntime;
